@@ -96,7 +96,8 @@ connman_bool_t __connman_profile_get_offlinemode(void)
 	return default_profile->offlinemode;
 }
 
-int __connman_profile_set_offlinemode(connman_bool_t offlinemode)
+int __connman_profile_set_offlinemode(connman_bool_t offlinemode,
+					connman_bool_t all_devices)
 {
 	DBG("offlinemode %d", offlinemode);
 
@@ -109,7 +110,8 @@ int __connman_profile_set_offlinemode(connman_bool_t offlinemode)
 	default_profile->offlinemode = offlinemode;
 	offlinemode_changed(default_profile);
 
-	__connman_device_set_offlinemode(offlinemode);
+	if (all_devices)
+		__connman_device_set_offlinemode(offlinemode);
 
 	return 0;
 }
@@ -479,7 +481,7 @@ static int profile_init(void)
 		g_dir_close(dir);
 	}
 
-	if (g_hash_table_size(profile_hash) == 0)
+	if (default_profile == NULL)
 		create_profile(PROFILE_DEFAULT_IDENT, "Default", NULL);
 
 	profiles_changed();
